==> llm-docs-0.1.5.tgz: package/docs/development/best-practices.md <==
---
id: development-best-practices
---
# Contributing Guide

This document provides guidelines and instructions for contributing to the LLM Platform AI Platform.

## 🚦 TDD First Approach

**IMPORTANT:** All development in this project follows strict Test-Driven Development (TDD):

1. **Tests are always written first**
2. **Only then is code written to pass those tests**
3. **No exceptions to this rule are permitted**

For detailed TDD requirements, see [Testing Requirements](./testing_requirements) and [TDD Enforcement Policy](./tdd_enforcement).

## Getting Started

### Prerequisites

- Node.js (v18+)
- npm (v9+)
- Git
- Docker (for containerized development)
- Kubernetes (for deployment testing)
- Drupal 11 (for llm_platform_recipe development)

### Setting Up Development Environment

1. **Clone the repository**

   ```bash
   git clone https://github.com/example/bluefly-ai-platform.git
   cd bluefly-ai-platform
   ```

2. **Install dependencies for a specific project**

   ```bash
   cd bfapi  # or another project directory
   npm install
   ```

3. **Set up environment variables**

   Copy the example environment file:

   ```bash
   cp .env.example .env
   ```

   Edit the `.env` file with your specific configuration.

4. **Start development server**

   ```bash
   npm run dev
   ```

## Development Workflow

### 1. Create a Feature Branch

```bash
git checkout -b feature/feature-name
```

Use the following branch naming conventions:
- `feature/` - for new features
- `bugfix/` - for bug fixes
- `refactor/` - for code refactoring
- `docs/` - for documentation updates
- `test/` - for test improvements

### 2. Write Tests First (RED Phase)

Always begin by writing tests that define the expected behavior. These tests should initially fail (RED phase).

Example:

```typescript
// __tests__/MyFeature.test.ts
describe('MyFeature', () => {
  it('should perform the expected action', async () => {
    const result = await myFeature.performAction();
    expect(result.status).toBe('success');
    expect(result.data).toHaveProperty('id');
  });
  
  it('should handle errors correctly', async () => {
    const result = await myFeature.performAction(invalidInput);
    expect(result.status).toBe('error');
    expect(result.error).toHaveProperty('code');
  });
});
```

Run the tests to verify they fail:

```bash
npm test
```

### 3. Implement the Feature (GREEN Phase)

Write the minimal code necessary to make the tests pass:

```typescript
// src/MyFeature.ts
export class MyFeature {
  async performAction(input?: any) {
    try {
      // Implementation goes here
      return { status: 'success', data: { id: 'generated-id' } };
    } catch (error) {
      return { status: 'error', error: { code: 'INVALID_INPUT' } };
    }
  }
}
```

Run the tests again to verify they pass:

```bash
npm test
```

### 4. Refactor the Code (REFACTOR Phase)

Improve the code while keeping the tests passing:

```bash
npm test -- --watch  # Run tests in watch mode during refactoring
```

### 5. Document Your Changes

Add or update documentation as needed:

- Update README.md if necessary
- Add JSDoc comments to your code
- Create or update documentation files in the docs directory

### 6. Run Linting and Type Checking

```bash
npm run lint
npm run typecheck
```

Fix any issues identified by the linter or type checker.

### 7. Create a Pull Request

Push your changes and create a pull request:

```bash
git push -u origin feature/feature-name
```

Go to the repository on GitHub and create a pull request with a detailed description of your changes.

## Pull Request Guidelines

### PR Title Format

Use the following format for PR titles:

```
[Component] Brief description of the change
```

Example: `[bfapi] Implement JWT authentication for API endpoints`

### PR Description Template

```markdown
## Description
A clear and concise description of the changes.

## Type of Change
- [ ] New feature
- [ ] Bug fix
- [ ] Performance improvement
- [ ] Refactoring
- [ ] Documentation update
- [ ] Test improvement

## Test Coverage
Describe how you tested these changes.

## TDD Compliance
Explain how you followed the TDD approach (tests first, then implementation).

## Breaking Changes
List any breaking changes and migration steps if applicable.

## Related Issues
Closes #123, Addresses #456
```

### Code Review Process

1. All PRs require at least one review before merging
2. Automated checks must pass (CI pipeline, tests, linting)
3. Address all reviewer comments
4. Maintain a respectful and constructive dialogue during reviews

## Code Style and Standards

### TypeScript/JavaScript

- Use TypeScript for all new code
- Follow the project's ESLint and Prettier configuration
- Use functional programming patterns where appropriate
- Write pure functions when possible
- Use asynchronous code with async/await (avoid raw promises)

### PHP (Drupal)

- Follow PSR-4 for class autoloading
- Follow PSR-12 for coding style
- Use dependency injection for services
- Follow Drupal coding standards for module development

### Testing

- Aim for 95%+ test coverage
- Include unit, integration, and e2e tests as appropriate
- Mock external dependencies
- Use descriptive test names that explain the expected behavior

### Documentation

- Document all public APIs with JSDoc comments
- Keep documentation up-to-date with code changes
- Use clear, concise language
- Include examples for complex functionality

## Component-Specific Guidelines

### API Gateway (bfapi)

- Follow RESTful API design principles
- Document all endpoints with OpenAPI specification
- Implement proper error handling and status codes
- Ensure all endpoints have authentication and authorization

### LLM Inference (bfllm)

- Design for model agnosticism
- Implement proper error handling for model inference
- Optimize for performance and resource usage
- Document model capabilities and limitations

### MCP Protocol (llm-mcp)

- Ensure backward compatibility in protocol changes
- Document all protocol messages and events
- Implement proper error handling for network issues
- Test with various tool providers

### Drupal Recipe (llm_platform_recipe)

- Follow Drupal best practices for recipe development
- Document installation and configuration steps
- Test with clean Drupal installations
- Ensure compatibility with required modules

## Versioning and Releases

We use semantic versioning (SEMVER):

- **MAJOR** version for incompatible API changes
- **MINOR** version for new functionality in a backward-compatible manner
- **PATCH** version for backward-compatible bug fixes

## Community and Communication

- Join our Slack channel for discussions
- Participate in weekly development meetings
- Ask questions in GitHub Discussions
- Report bugs and request features through GitHub Issues

## License and Legal

- All contributions must be licensed under the project's license
- Contributors retain copyright to their contributions
- Code of Conduct applies to all community interactions

## Continuous Integration

Our CI pipeline runs the following checks on all PRs:

- Linting and code style
- Type checking
- Unit and integration tests
- Build verification
- OpenAPI specification validation
- Security vulnerability scanning

## Recognition

Contributors are recognized in the following ways:

- Listed in the CONTRIBUTORS.md file
- Mentioned in release notes for significant contributions
- Featured in project showcases for major features

## Troubleshooting

If you encounter issues during development, refer to:

- [Troubleshooting Guide](./troubleshooting)
- GitHub Issues for known problems
- Developer community on Slack

---

Thank you for contributing to the LLM Platform AI Platform! Your efforts help make this project better for everyone.

==> llm-docs-1.0.1.tgz: package/docs/development/best-practices.md <==
---
id: development-best-practices
---
# Contributing Guide

This document provides guidelines and instructions for contributing to the Bluefly AI Platform.

## 🚦 TDD First Approach

**IMPORTANT:** All development in this project follows strict Test-Driven Development (TDD):

1. **Tests are always written first**
2. **Only then is code written to pass those tests**
3. **No exceptions to this rule are permitted**

For detailed TDD requirements, see [Testing Requirements](./testing_requirements) and [TDD Enforcement Policy](./tdd_enforcement).

## Getting Started

### Prerequisites

- Node.js (v18+)
- npm (v9+)
- Git
- Docker (for containerized development)
- Kubernetes (for deployment testing)
- Drupal 11 (for llm_platform_recipe development)

### Setting Up Development Environment

1. **Clone the repository**

   ```bash
   git clone https://github.com/example/bluefly-ai-platform.git
   cd bluefly-ai-platform
   ```

2. **Install dependencies for a specific project**

   ```bash
   cd bfapi  # or another project directory
   npm install
   ```

3. **Set up environment variables**

   Copy the example environment file:

   ```bash
   cp .env.example .env
   ```

   Edit the `.env` file with your specific configuration.

4. **Start development server**

   ```bash
   npm run dev
   ```

## Development Workflow

### 1. Create a Feature Branch

```bash
git checkout -b feature/feature-name
```

Use the following branch naming conventions:
- `feature/` - for new features
- `bugfix/` - for bug fixes
- `refactor/` - for code refactoring
- `docs/` - for documentation updates
- `test/` - for test improvements

### 2. Write Tests First (RED Phase)

Always begin by writing tests that define the expected behavior. These tests should initially fail (RED phase).

Example:

```typescript
// __tests__/MyFeature.test.ts
describe('MyFeature', () => {
  it('should perform the expected action', async () => {
    const result = await myFeature.performAction();
    expect(result.status).toBe('success');
    expect(result.data).toHaveProperty('id');
  });
  
  it('should handle errors correctly', async () => {
    const result = await myFeature.performAction(invalidInput);
    expect(result.status).toBe('error');
    expect(result.error).toHaveProperty('code');
  });
});
```

Run the tests to verify they fail:

```bash
npm test
```

### 3. Implement the Feature (GREEN Phase)

Write the minimal code necessary to make the tests pass:

```typescript
// src/MyFeature.ts
export class MyFeature {
  async performAction(input?: any) {
    try {
      // Implementation goes here
      return { status: 'success', data: { id: 'generated-id' } };
    } catch (error) {
      return { status: 'error', error: { code: 'INVALID_INPUT' } };
    }
  }
}
```

Run the tests again to verify they pass:

```bash
npm test
```

### 4. Refactor the Code (REFACTOR Phase)

Improve the code while keeping the tests passing:

```bash
npm test -- --watch  # Run tests in watch mode during refactoring
```

### 5. Document Your Changes

Add or update documentation as needed:

- Update README.md if necessary
- Add JSDoc comments to your code
- Create or update documentation files in the docs directory

### 6. Run Linting and Type Checking

```bash
npm run lint
npm run typecheck
```

Fix any issues identified by the linter or type checker.

### 7. Create a Pull Request

Push your changes and create a pull request:

```bash
git push -u origin feature/feature-name
```

Go to the repository on GitHub and create a pull request with a detailed description of your changes.

## Pull Request Guidelines

### PR Title Format

Use the following format for PR titles:

```
[Component] Brief description of the change
```

Example: `[bfapi] Implement JWT authentication for API endpoints`

### PR Description Template

```markdown
## Description
A clear and concise description of the changes.

## Type of Change
- [ ] New feature
- [ ] Bug fix
- [ ] Performance improvement
- [ ] Refactoring
- [ ] Documentation update
- [ ] Test improvement

## Test Coverage
Describe how you tested these changes.

## TDD Compliance
Explain how you followed the TDD approach (tests first, then implementation).

## Breaking Changes
List any breaking changes and migration steps if applicable.

## Related Issues
Closes #123, Addresses #456
```

### Code Review Process

1. All PRs require at least one review before merging
2. Automated checks must pass (CI pipeline, tests, linting)
3. Address all reviewer comments
4. Maintain a respectful and constructive dialogue during reviews

## Code Style and Standards

### TypeScript/JavaScript

- Use TypeScript for all new code
- Follow the project's ESLint and Prettier configuration
- Use functional programming patterns where appropriate
- Write pure functions when possible
- Use asynchronous code with async/await (avoid raw promises)

### PHP (Drupal)

- Follow PSR-4 for class autoloading
- Follow PSR-12 for coding style
- Use dependency injection for services
- Follow Drupal coding standards for module development

### Testing

- Aim for 95%+ test coverage
- Include unit, integration, and e2e tests as appropriate
- Mock external dependencies
- Use descriptive test names that explain the expected behavior

### Documentation

- Document all public APIs with JSDoc comments
- Keep documentation up-to-date with code changes
- Use clear, concise language
- Include examples for complex functionality

## Component-Specific Guidelines

### API Gateway (bfapi)

- Follow RESTful API design principles
- Document all endpoints with OpenAPI specification
- Implement proper error handling and status codes
- Ensure all endpoints have authentication and authorization

### LLM Inference (bfllm)

- Design for model agnosticism
- Implement proper error handling for model inference
- Optimize for performance and resource usage
- Document model capabilities and limitations

### MCP Protocol (bfmcp)

- Ensure backward compatibility in protocol changes
- Document all protocol messages and events
- Implement proper error handling for network issues
- Test with various tool providers

### Drupal Recipe (llm_platform_recipe)

- Follow Drupal best practices for recipe development
- Document installation and configuration steps
- Test with clean Drupal installations
- Ensure compatibility with required modules

## Versioning and Releases

We use semantic versioning (SEMVER):

- **MAJOR** version for incompatible API changes
- **MINOR** version for new functionality in a backward-compatible manner
- **PATCH** version for backward-compatible bug fixes

## Community and Communication

- Join our Slack channel for discussions
- Participate in weekly development meetings
- Ask questions in GitHub Discussions
- Report bugs and request features through GitHub Issues

## License and Legal

- All contributions must be licensed under the project's license
- Contributors retain copyright to their contributions
- Code of Conduct applies to all community interactions

## Continuous Integration

Our CI pipeline runs the following checks on all PRs:

- Linting and code style
- Type checking
- Unit and integration tests
- Build verification
- OpenAPI specification validation
- Security vulnerability scanning

## Recognition

Contributors are recognized in the following ways:

- Listed in the CONTRIBUTORS.md file
- Mentioned in release notes for significant contributions
- Featured in project showcases for major features

## Troubleshooting

If you encounter issues during development, refer to:

- [Troubleshooting Guide](./troubleshooting)
- GitHub Issues for known problems
- Developer community on Slack

---

Thank you for contributing to the Bluefly AI Platform! Your efforts help make this project better for everyone.
